@@ -99,7 +99,7 @@ read.cross.mm <-
         if(flag == 0) {
             flag <- 1
             if(!is.na(match("intercross", a))) type <- "f2"
-            else if(!is.na(match("backcross", a))) type <- "bc"
+            else if(!is.na(match("backcross", a)) || !is.na(match("bc", a))) type <- "bc"
             else
                 stop("File indicates invalid cross type: ", a[length(a)], ".")
         }
@@ -253,11 +253,16 @@ read.cross.mm <-
             tempchr <- as.numeric(tempchr)
             if(includes.pos) neworder <- order(tempchr, pos)
             else neworder <- order(tempchr)
+        } else {
+            # prevent reordering of chromosomes
+            tempchr <- factor(chr, levels=unique(chr))
 
-            chr <- chr[neworder]
-            if(includes.pos) pos <- pos[neworder]
-            markers <- markers[neworder]
+            if(includes.pos) neworder <- order(tempchr, pos)
+            else neworder <- order(tempchr)
         }
+        chr <- chr[neworder]
+        if(includes.pos) pos <- pos[neworder]
+        markers <- markers[neworder]
     }
 
     Geno <- vector("list",length(unique(chr)))
